@@ -1,5 +1,3 @@
-import asyncio
-import contextlib
 import json
 import logging
 import os
@@ -10,10 +8,14 @@ import yaml  # type: ignore
 from filelock import FileLock
 from pydantic import ValidationError
 
-from mcp_scan_server.models import DEFAULT_GUARDRAIL_CONFIG, GuardrailConfigFile
-
 from .models import Entity, ScannedEntities, ScannedEntity, entity_type_to_str, hash_entity
 
+try:
+    from mcp_scan_server.models import DEFAULT_GUARDRAIL_CONFIG, GuardrailConfigFile
+except ImportError:
+    DEFAULT_GUARDRAIL_CONFIG = ""
+    GuardrailConfigFile = None
+
 # Set up logger for this module
 logger = logging.getLogger(__name__)
 
@@ -26,7 +28,11 @@ class Storage:
         logger.debug("Expanded path: %s", self.path)
         self.scanned_entities: ScannedEntities = ScannedEntities({})
         self.whitelist: dict[str, str] = {}
-        self.guardrails_config: GuardrailConfigFile = GuardrailConfigFile()
+        
+        if GuardrailConfigFile is not None:
+            self.guardrails_config: GuardrailConfigFile = GuardrailConfigFile()
+        else:
+            self.guardrails_config = None
 
         self.detect_and_convert_legacy_storage()
         self.init_from_path()
@@ -34,7 +40,6 @@ class Storage:
         self._lock_path = os.path.join(self.path, ".mcp-scan.lock")
         self._lock = FileLock(self._lock_path, timeout=10)
 
-
     def detect_and_convert_legacy_storage(self):
         if os.path.isfile(self.path):
             rich.print(f"[bold]Legacy storage file detected at {self.path}, converting to new format[/bold]")
@@ -87,21 +92,22 @@ class Storage:
                     self.whitelist = json.load(f)
                     logger.info("Successfully loaded whitelist with %d entries", len(self.whitelist))
 
-            guardrails_config_path = os.path.join(self.path, "guardrails_config.yml")
-            if os.path.exists(guardrails_config_path):
-                with open(guardrails_config_path) as f:
-                    try:
-                        guardrails_config_data = yaml.safe_load(f.read()) or {}
-                        self.guardrails_config = GuardrailConfigFile.model_validate(guardrails_config_data)
-                    except yaml.YAMLError as e:
-                        rich.print(
-                            f"[bold red]Could not parse guardrails config file {guardrails_config_path}: {e}[/bold red]"
-                        )
-                    except ValidationError as e:
-                        rich.print(
-                            f"[bold red]Could not validate guardrails config file "
-                            f"{guardrails_config_path}: {e}[/bold red]"
-                        )
+            if GuardrailConfigFile is not None:
+                guardrails_config_path = os.path.join(self.path, "guardrails_config.yml")
+                if os.path.exists(guardrails_config_path):
+                    with open(guardrails_config_path) as f:
+                        try:
+                            guardrails_config_data = yaml.safe_load(f.read()) or {}
+                            self.guardrails_config = GuardrailConfigFile.model_validate(guardrails_config_data)
+                        except yaml.YAMLError as e:
+                            rich.print(
+                                f"[bold red]Could not parse guardrails config file {guardrails_config_path}: {e}[/bold red]"
+                            )
+                        except ValidationError as e:
+                            rich.print(
+                                f"[bold red]Could not validate guardrails config file "
+                                f"{guardrails_config_path}: {e}[/bold red]"
+                            )
 
     def reset_whitelist(self) -> None:
         logger.info("Resetting whitelist")
@@ -138,7 +144,7 @@ class Storage:
 
         self.scanned_entities.root[key] = new_data
         return changed, messages
-    
+
     def get_background_scan_path(self):
         return os.path.join(self.path, "background_scan.json")
 
@@ -153,7 +159,6 @@ class Storage:
                 f.write("")
         return file
 
-
     def print_whitelist(self) -> None:
         logger.info("Printing whitelist with %d entries", len(self.whitelist))
         whitelist_keys = sorted(self.whitelist.keys())
@@ -184,6 +189,8 @@ class Storage:
 
         Returns the path to the guardrails config file.
         """
+        if GuardrailConfigFile is None:
+            return None
         guardrails_config_path = os.path.join(self.path, "guardrails_config.yml")
         with self._lock:
             if not os.path.exists(guardrails_config_path):
