@@ -1,6 +1,6 @@
+from .lib import inspect, scan
 from .MCPScanner import MCPScanner
 from .version import version_info
-from .lib import scan, inspect
 
-__all__ = ["MCPScanner", "scan", "inspect"]
+__all__ = ["MCPScanner", "inspect", "scan"]
 __version__ = version_info
