@@ -1,24 +1,25 @@
-from unittest.mock import AsyncMock, patch
-
 import json
 import sys
+from unittest.mock import AsyncMock, patch
+from urllib.parse import parse_qsl, urlsplit
 
 import aiohttp
+import httpx
 import pytest
 
+from mcp_scan.MCPScanner import MCPScanner
 from mcp_scan.models import (
+    RemoteServer,
     ScanError,
     ScanPathResult,
+    ScanUserInfo,
     ServerScanResult,
     StdioServer,
-    ScanUserInfo
 )
 from mcp_scan.upload import (
     get_user_info,
     upload,  # Make sure this import is correct
 )
-from mcp_scan.MCPScanner import MCPScanner
-import httpx
 
 
 def test_opt_out_does_not_create_identity():
@@ -205,8 +206,12 @@ async def test_get_servers_from_path_sets_file_not_found_error_and_uploads_paylo
     Patch MCPScanner.get_servers_from_path dependencies so that scan_mcp_config_file raises FileNotFoundError
     and ensure the resulting ScanPathResult has error message "file does not exist" and is uploaded.
     """
-    with patch.object(sys.modules['mcp_scan.MCPScanner'], "scan_mcp_config_file", side_effect=FileNotFoundError("missing")), \
-         patch("mcp_scan.upload.get_user_info") as mock_get_user_info:
+    with (
+        patch.object(
+            sys.modules["mcp_scan.MCPScanner"], "scan_mcp_config_file", side_effect=FileNotFoundError("missing")
+        ),
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
 
         mock_http_response = AsyncMock(status=200)
@@ -228,7 +233,7 @@ async def test_get_servers_from_path_sets_file_not_found_error_and_uploads_paylo
             sent_result = payload["scan_path_results"][0]
             assert sent_result["servers"] is None
             assert sent_result["path"] == "/nonexistent/path"
-            assert sent_result["error"]["message"] == "file does not exist"
+            assert sent_result["error"]["message"] == "file /nonexistent/path does not exist"
             assert sent_result["error"]["is_failure"] is False
             assert "missing" in (sent_result["error"].get("exception") or "")
 
@@ -239,8 +244,12 @@ async def test_get_servers_from_path_sets_parse_error_and_uploads_payload():
     Patch MCPScanner.get_servers_from_path dependencies so that scan_mcp_config_file raises a generic Exception
     and ensure the resulting ScanPathResult has error message "could not parse file" and is uploaded.
     """
-    with patch.object(sys.modules['mcp_scan.MCPScanner'], "scan_mcp_config_file", side_effect=Exception("parse failure")), \
-         patch("mcp_scan.upload.get_user_info") as mock_get_user_info:
+    with (
+        patch.object(
+            sys.modules["mcp_scan.MCPScanner"], "scan_mcp_config_file", side_effect=Exception("parse failure")
+        ),
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
 
         mock_http_response = AsyncMock(status=200)
@@ -262,7 +271,7 @@ async def test_get_servers_from_path_sets_parse_error_and_uploads_payload():
             sent_result = payload["scan_path_results"][0]
             assert sent_result["servers"] is None
             assert sent_result["path"] == "/bad/config"
-            assert sent_result["error"]["message"] == "could not parse file"
+            assert sent_result["error"]["message"] == "could not parse file /bad/config"
             assert sent_result["error"]["is_failure"] is True
             assert "parse failure" in (sent_result["error"].get("exception") or "")
 
@@ -273,13 +282,20 @@ async def test_scan_server_sets_http_status_error_and_uploads_payload():
     Patch MCPScanner to return a server, then make check_server_with_timeout raise HTTPStatusError and
     ensure the server-level error message "server returned HTTP status code" is included on upload.
     """
+
     class DummyCfg:
         def get_servers(self):
             return {"srv": StdioServer(command="echo")}
 
-    with patch.object(sys.modules['mcp_scan.MCPScanner'], "scan_mcp_config_file", return_value=DummyCfg()), \
-         patch.object(sys.modules['mcp_scan.MCPScanner'], "check_server_with_timeout", side_effect=httpx.HTTPStatusError("bad", request=None, response=None)), \
-         patch("mcp_scan.upload.get_user_info") as mock_get_user_info:
+    with (
+        patch.object(sys.modules["mcp_scan.MCPScanner"], "scan_mcp_config_file", return_value=DummyCfg()),
+        patch.object(
+            sys.modules["mcp_scan.MCPScanner"],
+            "check_server_with_timeout",
+            side_effect=httpx.HTTPStatusError("bad", request=None, response=None),
+        ),
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
 
         mock_http_response = AsyncMock(status=200)
@@ -311,13 +327,18 @@ async def test_scan_server_sets_could_not_start_error_and_uploads_payload():
     Patch MCPScanner to return a server, then make check_server_with_timeout raise a generic Exception and
     ensure the server-level error message "could not start server" is included on upload.
     """
+
     class DummyCfg:
         def get_servers(self):
             return {"srv": StdioServer(command="echo")}
 
-    with patch.object(sys.modules['mcp_scan.MCPScanner'], "scan_mcp_config_file", return_value=DummyCfg()), \
-         patch.object(sys.modules['mcp_scan.MCPScanner'], "check_server_with_timeout", side_effect=Exception("spawn failed")), \
-         patch("mcp_scan.upload.get_user_info") as mock_get_user_info:
+    with (
+        patch.object(sys.modules["mcp_scan.MCPScanner"], "scan_mcp_config_file", return_value=DummyCfg()),
+        patch.object(
+            sys.modules["mcp_scan.MCPScanner"], "check_server_with_timeout", side_effect=Exception("spawn failed")
+        ),
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
 
         mock_http_response = AsyncMock(status=200)
@@ -349,9 +370,10 @@ async def test_upload_retries_on_network_error():
     """
     mock_result = ScanPathResult(path="/test/path")
 
-    with patch("mcp_scan.upload.get_user_info") as mock_get_user_info, \
-         patch("mcp_scan.upload.asyncio.sleep") as mock_sleep:
-        
+    with (
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+        patch("mcp_scan.upload.asyncio.sleep") as mock_sleep,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
         mock_sleep.return_value = None  # Speed up tests by not actually sleeping
 
@@ -367,7 +389,7 @@ async def test_upload_retries_on_network_error():
 
             # Verify that post was attempted 3 times
             assert mock_post_method.call_count == 3
-            
+
             # Verify that sleep was called between retries (2 times for 3 attempts)
             assert mock_sleep.call_count == 2
             # Verify exponential backoff: 1s, 2s
@@ -382,9 +404,10 @@ async def test_upload_retries_on_server_error():
     """
     mock_result = ScanPathResult(path="/test/path")
 
-    with patch("mcp_scan.upload.get_user_info") as mock_get_user_info, \
-         patch("mcp_scan.upload.asyncio.sleep") as mock_sleep:
-        
+    with (
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+        patch("mcp_scan.upload.asyncio.sleep") as mock_sleep,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
         mock_sleep.return_value = None
 
@@ -404,7 +427,7 @@ async def test_upload_retries_on_server_error():
 
             # Verify that post was attempted 3 times
             assert mock_post_method.call_count == 3
-            
+
             # Verify that sleep was called between retries
             assert mock_sleep.call_count == 2
 
@@ -416,9 +439,10 @@ async def test_upload_does_not_retry_on_client_error():
     """
     mock_result = ScanPathResult(path="/test/path")
 
-    with patch("mcp_scan.upload.get_user_info") as mock_get_user_info, \
-         patch("mcp_scan.upload.asyncio.sleep") as mock_sleep:
-        
+    with (
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+        patch("mcp_scan.upload.asyncio.sleep") as mock_sleep,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
         mock_sleep.return_value = None
 
@@ -438,11 +462,79 @@ async def test_upload_does_not_retry_on_client_error():
 
             # Verify that post was attempted only once (no retries on 4xx)
             assert mock_post_method.call_count == 1
-            
+
             # Verify that sleep was NOT called
             mock_sleep.assert_not_called()
 
 
+@pytest.mark.asyncio
+async def test_scan_path_redacts_remote_url_query_and_headers():
+    """
+    Ensure RemoteServer headers are redacted and URL query parameter values are replaced with REDACTED.
+    Uses scanner.scan_path to exercise _redact_server in the normal flow.
+    """
+
+    class DummyCfg:
+        def get_servers(self):
+            return {
+                "remote": RemoteServer(
+                    url="https://api.example.com/endpoint?token=abc123&api_key=xyz",
+                    type="http",
+                    headers={"Authorization": "Bearer secret", "X-Custom": "value"},
+                )
+            }
+
+    with (
+        patch.object(sys.modules["mcp_scan.MCPScanner"], "scan_mcp_config_file", return_value=DummyCfg()),
+        patch.object(sys.modules["mcp_scan.MCPScanner"], "check_server_with_timeout", return_value=None),
+    ):
+        async with MCPScanner(files=["/dummy/path"]) as scanner:
+            result = await scanner.scan_path("/dummy/path", inspect_only=True)
+
+    assert result.servers is not None and len(result.servers) == 1
+    srv = result.servers[0]
+    assert isinstance(srv.server, RemoteServer)
+    # Headers should be redacted
+    assert srv.server.headers["Authorization"] == "**REDACTED**"
+    assert srv.server.headers["X-Custom"] == "**REDACTED**"
+    # URL query param values should be redacted (keys preserved)
+    parts = urlsplit(srv.server.url)
+    qs = dict(parse_qsl(parts.query, keep_blank_values=True))
+    assert qs.get("token") == "**REDACTED**"
+    assert qs.get("api_key") == "**REDACTED**"
+
+
+@pytest.mark.asyncio
+async def test_scan_path_redacts_stdio_env_vars():
+    """
+    Ensure StdioServer environment variable values are redacted via scanner.scan_path.
+    """
+
+    class DummyCfg:
+        def get_servers(self):
+            return {
+                "stdio": StdioServer(
+                    command="echo",
+                    args=["hello"],
+                    env={"SECRET": "shh", "API_TOKEN": "tok"},
+                )
+            }
+
+    with (
+        patch.object(sys.modules["mcp_scan.MCPScanner"], "scan_mcp_config_file", return_value=DummyCfg()),
+        patch.object(sys.modules["mcp_scan.MCPScanner"], "check_server_with_timeout", return_value=None),
+    ):
+        async with MCPScanner(files=["/dummy/path"]) as scanner:
+            result = await scanner.scan_path("/dummy/path", inspect_only=True)
+
+    assert result.servers is not None and len(result.servers) == 1
+    srv = result.servers[0]
+    assert isinstance(srv.server, StdioServer)
+    # Env values should be redacted; keys preserved
+    assert srv.server.env["SECRET"] == "**REDACTED**"
+    assert srv.server.env["API_TOKEN"] == "**REDACTED**"
+
+
 @pytest.mark.asyncio
 async def test_upload_succeeds_on_second_attempt():
     """
@@ -450,16 +542,17 @@ async def test_upload_succeeds_on_second_attempt():
     """
     mock_result = ScanPathResult(path="/test/path")
 
-    with patch("mcp_scan.upload.get_user_info") as mock_get_user_info, \
-         patch("mcp_scan.upload.asyncio.sleep") as mock_sleep:
-        
+    with (
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+        patch("mcp_scan.upload.asyncio.sleep") as mock_sleep,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
         mock_sleep.return_value = None
 
         # First attempt fails, second succeeds
         mock_error_context = AsyncMock()
         mock_error_context.__aenter__.side_effect = aiohttp.ClientError("Connection refused")
-        
+
         mock_success_response = AsyncMock(status=200)
         mock_success_response.json.return_value = []
         mock_success_context = AsyncMock()
@@ -474,7 +567,7 @@ async def test_upload_succeeds_on_second_attempt():
 
             # Verify that post was attempted twice (failed once, succeeded on retry)
             assert mock_post_method.call_count == 2
-            
+
             # Verify that sleep was called once
             assert mock_sleep.call_count == 1
             mock_sleep.assert_called_once_with(1)  # First backoff is 1 second
@@ -487,9 +580,10 @@ async def test_upload_custom_max_retries():
     """
     mock_result = ScanPathResult(path="/test/path")
 
-    with patch("mcp_scan.upload.get_user_info") as mock_get_user_info, \
-         patch("mcp_scan.upload.asyncio.sleep") as mock_sleep:
-        
+    with (
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+        patch("mcp_scan.upload.asyncio.sleep") as mock_sleep,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
         mock_sleep.return_value = None
 
@@ -505,7 +599,7 @@ async def test_upload_custom_max_retries():
 
             # Verify that post was attempted 5 times
             assert mock_post_method.call_count == 5
-            
+
             # Verify that sleep was called 4 times (between 5 attempts)
             assert mock_sleep.call_count == 4
 
@@ -517,9 +611,10 @@ async def test_upload_exponential_backoff():
     """
     mock_result = ScanPathResult(path="/test/path")
 
-    with patch("mcp_scan.upload.get_user_info") as mock_get_user_info, \
-         patch("mcp_scan.upload.asyncio.sleep") as mock_sleep:
-        
+    with (
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+        patch("mcp_scan.upload.asyncio.sleep") as mock_sleep,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
         mock_sleep.return_value = None
 
@@ -546,9 +641,10 @@ async def test_upload_does_not_retry_on_unexpected_error():
     """
     mock_result = ScanPathResult(path="/test/path")
 
-    with patch("mcp_scan.upload.get_user_info") as mock_get_user_info, \
-         patch("mcp_scan.upload.asyncio.sleep") as mock_sleep:
-        
+    with (
+        patch("mcp_scan.upload.get_user_info") as mock_get_user_info,
+        patch("mcp_scan.upload.asyncio.sleep") as mock_sleep,
+    ):
         mock_get_user_info.return_value = ScanUserInfo()
         mock_sleep.return_value = None
 
@@ -565,6 +661,6 @@ async def test_upload_does_not_retry_on_unexpected_error():
 
             # Verify that post was attempted only once (no retry on unexpected errors)
             assert mock_post_method.call_count == 1
-            
+
             # Verify that sleep was NOT called
             mock_sleep.assert_not_called()
